.. ekfsm documentation master file, created by
   sphinx-quickstart on Thu Oct 10 14:07:51 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to EKF System Management Library documentation!
========================================================


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro.rst
   boards.rst
   reference/index
